@@ -15,6 +15,12 @@ class ManyToManyField(models.ManyToManyField):
         defaults.update(kwargs)
         return super(ManyToManyField, self).formfield(**defaults)
 
+    def south_field_triple(self):
+        from south.modelsinspector import introspector
+        field_class = "django.db.models.fields.ManyToManyField"
+        args, kwargs = introspector(self)
+        return (field_class, args, kwargs)
+
 class ForeignKey(models.ForeignKey):
     def __init__(self, to, **kwargs):
         self.model_str = u"%s.%s"%(to.__module__, to.__name__)
@@ -26,4 +32,10 @@ class ForeignKey(models.ForeignKey):
             "model_str": self.model_str,
         }
         defaults.update(kwargs)
-        return super(ForeignKey, self).formfield(**defaults)
\ No newline at end of file
+        return super(ForeignKey, self).formfield(**defaults)
+
+    def south_field_triple(self):
+        from south.modelsinspector import introspector
+        field_class = "django.db.models.fields.ForeignKey"
+        args, kwargs = introspector(self)
+        return (field_class, args, kwargs)
\ No newline at end of file
